import 'package:flutter/material.dart';
import 'package:pmu_project/presentation/details_page/details_page.dart';
import 'package:flutter/cupertino.dart';
import 'package:pmu_project/domain/models/card.dart';

part 'card.dart';

class HomePage extends StatefulWidget {
  const HomePage({super.key, required this.title});

  final String title;

  @override
  State<HomePage> createState() => _HomePageState();
}

class _HomePageState extends State<HomePage> {
  final Color _color = Color.fromARGB(231, 224, 243, 191);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        backgroundColor: _color,
        title: Text(widget.title),
      ),
      body: const Body(),
    );
  }
}

class Body extends StatelessWidget {
  const Body({super.key}); // ключи

  @override
  Widget build(BuildContext context) {
    final data = [
      CardData('the tapok one',
          descriptionText: 'he has an amazing tapok',
          icon: Icons.abc,
          imageUrl:
          'https://sun165-1.userapi.com/impg/j-ZnE55SoxJuxbDst9BoJrS__UXocF4da6lUPQ/5XrJ_S-0R9o.jpg?size=810x1080&quality=95&sign=45abca51d4f25317989df7d370630b69&type=album'),
      CardData('the judgy one',
          descriptionText: 'now he is lying in the bed, but when he is not, everyone should be careful',
          icon: Icons.access_alarm_outlined,
          imageUrl:
          'https://sun34-1.userapi.com/impg/5IEbax8DvqadOTjsd2QvO_4K9GLbvU2uPcJkkA/0CGHMQActFU.jpg?size=968x1080&quality=95&sign=6fcae468d5ca12aab4397106bc5df1ad&type=album'),
      CardData('the sleepy eepy one',
          descriptionText: 'incredibly powerful (when not sleepy)',
          icon: Icons.access_alarm_rounded,
          imageUrl:
          'https://sun165-2.userapi.com/impg/rPyrll39KOW1jawF0jNJfGYQQ0czceUbELeEjQ/xwhmmbiYKSw.jpg?size=810x1080&quality=95&sign=3d1324a18563eda6ad0cb10a751860dd&type=album'),
    ];

    return Center(
      child: SingleChildScrollView(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: data.map((data) {
            return _Card.fromData(
              data,
              onLike: (String title, bool isLiked) =>
                  _showSnackBar(context, title, isLiked),
              onTap: () => _navToDetails(context, data),
            );
          }).toList(),
        ),
      ),
    );
  }

  void _navToDetails(BuildContext context, CardData data) {
    Navigator.push(
      context,
      CupertinoPageRoute(builder: (context) => DetailsPage(data)),
    );
  }

  void _showSnackBar(BuildContext context, String title, bool isLiked) {
    WidgetsBinding.instance.addPostFrameCallback((_) {
      ScaffoldMessenger.of(context).showSnackBar(SnackBar(
        content: Text(
          'Fighter $title ${isLiked ? 'is chosen!' : 'does not chosen...'}',
          style: Theme.of(context).textTheme.bodyLarge,
        ),
        backgroundColor: Color.fromARGB(231, 224, 243, 191),
        duration: const Duration(seconds: 1),
      ));
    });
  }
}
